starcluster

Package starcluster |
[hide private]
[frames] | no frames]

# Package starcluster

source code

Version: 0.92rc1

Author: Justin Riley (justin.t.riley@gmail.com)

Submodules | [hide private]
starcluster.awsutils: EC2/S3 Utility Classes starcluster.balancers starcluster.balancers.sge starcluster.balancers.sge.visualizer: StarCluster SunGrinEngine stats visualizer module starcluster.cli: StarCluster Command Line Interface: starcluster.cluster starcluster.clustersetup: clustersetup.py starcluster.commands starcluster.commands.addnode starcluster.commands.base starcluster.commands.completers starcluster.commands.createkey starcluster.commands.createvolume starcluster.commands.downloadimage starcluster.commands.ebsimage starcluster.commands.help starcluster.commands.listbuckets starcluster.commands.listclusters starcluster.commands.listimages starcluster.commands.listinstances starcluster.commands.listkeypairs starcluster.commands.listpublic starcluster.commands.listregions starcluster.commands.listspots starcluster.commands.listvolumes starcluster.commands.listzones starcluster.commands.loadbalance starcluster.commands.removeimage starcluster.commands.removekey starcluster.commands.removenode starcluster.commands.removevolume starcluster.commands.resizevolume starcluster.commands.restart starcluster.commands.runplugin starcluster.commands.s3image starcluster.commands.shell starcluster.commands.showbucket starcluster.commands.showconsole starcluster.commands.showimage starcluster.commands.spothistory starcluster.commands.sshinstance starcluster.commands.sshmaster starcluster.commands.sshnode starcluster.commands.start starcluster.commands.stop starcluster.commands.terminate starcluster.config starcluster.exception: StarCluster Exception Classes starcluster.image starcluster.iptools: Utitlities for dealing with ip addresses. starcluster.logger: StarCluster logging module starcluster.managers starcluster.node starcluster.optcomplete: Automatic completion for optparse module. starcluster.plugins starcluster.plugins.ipcluster starcluster.progressbar: Text progressbar library for python. starcluster.spinner starcluster.ssh: ssh.py Friendly Python SSH2 interface. starcluster.static: Module for storing static data structures starcluster.templates starcluster.templates.config starcluster.templates.sge starcluster.templates.user_msgs starcluster.tests starcluster.tests.mytestplugin starcluster.tests.templates starcluster.tests.templates.config starcluster.tests.templates.sge_balancer starcluster.tests.test_cluster_validation starcluster.tests.test_config starcluster.tests.test_sge_balancer starcluster.threadpool: ThreadPool module for StarCluster based on WorkerPool starcluster.utils: Utils module for StarCluster starcluster.volume

Functions | [hide private]
test() | source code

Variables | [hide private]
| __package__ = ``'``starcluster``'``